@@ -266,7 +266,15 @@ outbreaker <- function(dna=NULL, dates, idx.dna=NULL,
 
 
     ## BUILD OUTPUT ##
+    ## read table
     chains <- read.table(res.file.name, header=TRUE)
+
+    ## force numeric class for post, like, prior
+    ## (weird behaviour of read.table in some R versions)
+    chains$post <- as.numeric(chains$post)
+    chains$like <- as.numeric(chains$like)
+    chains$prior <- as.numeric(chains$prior)
+
     chains$run <- rep(1, nrow(chains))
     call <- match.call()
     res <- list(chains=chains, collec.dates=dates, w=w.dens[1:w.trunc], f=f.dens[1:f.trunc], D=D, idx.dna=idx.dna, tune.end=stopTuneAt,
@@ -406,6 +414,13 @@ outbreaker.parallel <- function(n.runs, parallel=require("parallel"), n.cores=NU
     res$n.runs <- n.runs
     res$call <- match.call()
 
+    ## force numeric class for post, like, prior
+    ## (weird behaviour of read.table in some R versions)
+    res$chains$post <- as.numeric(res$chains$post)
+    res$chains$like <- as.numeric(res$chains$like)
+    res$chains$prior <- as.numeric(res$chains$prior)
+
+
     ## RETURN RESULTS ##
     return(res)
 } # end outbreaker.parallel
